jffs2: rename devices_init () in common/jffs2.c

rename devices_init () in common/jffs2.c to
jffs2_devices_init (), because there is also a
devices_init () in common/devices.c.

Signed-off-by: Heiko Schocher <hs@denx.de>
diff --git a/common/cmd_jffs2.c b/common/cmd_jffs2.c
index 791a572..c2caade 100644
--- a/common/cmd_jffs2.c
+++ b/common/cmd_jffs2.c
@@ -1056,7 +1056,7 @@
  *
  * @return 0 on success, 1 otherwise
  */
-static int devices_init(void)
+static int jffs2_devices_init(void)
 {
 	last_parts[0] = '\0';
 	current_dev = NULL;
@@ -1471,12 +1471,12 @@
 	DEBUGF("\n---parse_mtdparts---\nmtdparts = %s\n\n", p);
 
 	/* delete all devices and partitions */
-	if (devices_init() != 0) {
+	if (jffs2_devices_init() != 0) {
 		printf("could not initialise device list\n");
 		return err;
 	}
 
 	/* re-read 'mtdparts' variable, devices_init may be updating env */
 	p = getenv("mtdparts");
 
 	if (strncmp(p, "mtdparts=", 9) != 0) {
@@ -1698,7 +1698,7 @@
 		ids_changed = 1;
 
 		if (parse_mtdids(ids) != 0) {
-			devices_init();
+			jffs2_devices_init();
 			return 1;
 		}
 
@@ -1731,7 +1731,7 @@
 
 	/* mtdparts variable was reset to NULL, delete all devices/partitions */
 	if (!parts && (last_parts[0] != '\0'))
-		return devices_init();
+		return jffs2_devices_init();
 
 	/* do not process current partition if mtdparts variable is null */
 	if (!parts)
@@ -2105,8 +2105,8 @@
 
 			setenv("mtdparts", NULL);
 
-			/* devices_init() calls current_save() */
-			return devices_init();
+			/* jffs2_devices_init() calls current_save() */
+			return jffs2_devices_init();
 		}
 	}
@@ -1471,12 +1471,12 @@
 	}
 
-	/* re-read 'mtdparts' variable, devices_init may be updating env */
+	/* re-read 'mtdparts' variable, jffs2_devices_init may be updating env */
 	p = getenv("mtdparts");
 